@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * CheckParamData.c
 *
@@ -22,7 +22,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <ctype.h>
@@ -304,7 +304,7 @@ void CheckParamData ( void )
 
       else if ( strcmp(&plot_types[index_plot_types], "histogram") == 0 )
          {
-         if ( (pchar = strchr("bB", stylechar1[iplot-1])) == NULL )
+         if ( (pchar = strchr("lbB", stylechar1[iplot-1])) == NULL )
             {
             size = strlen("Invalid or missing plot symbol for file:\n") + strlen(&filenames[index_filenames]);
             string = malloc(size + 1);
@@ -450,15 +450,16 @@ void CheckParamData ( void )
    index_bin_refs = 0;
    for ( i=1; i<=nplots; i++ )
       {
-      if ( strcmp(&bin_refs[index_bin_refs], "mean") != 0 &&
-           strcmp(&bin_refs[index_bin_refs], "zero") != 0 )
+      if ( strcmp(&bin_refs[index_bin_refs], "mean")     != 0 &&
+           strcmp(&bin_refs[index_bin_refs], "zero")     != 0 &&
+           strcmp(&bin_refs[index_bin_refs], "integers") != 0 )
          {
          ErrorDialog(error_str[13]);
          FreeMemory();
          exit(1);
          }
 
-      index_bin_refs = index_bin_refs + 5;
+      index_bin_refs = index_bin_refs + 9;
       }
 
 
