@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * DrawSymbols.c
 *
@@ -40,7 +40,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <math.h>
@@ -126,13 +126,27 @@ void DrawDashedLine ( GnomeCanvasPoints *points, guint32 fill_color_rgba, unsign
       }
 
 
-   /* Interpolate and draw dashed line */
+   /* Recalculate dash and space lengths */
    inc = dash + space;
    fspace = space/inc;
-   nlines = roundint((length_total + space)/inc);
-   inc = length_total/(nlines - fspace);
-   factor = length_total + fspace*inc;
+   if ( sqrt((x[npoints-1] - x[0])*(x[npoints-1] - x[0]) +
+             (y[npoints-1] - y[0])*(y[npoints-1] - y[0])) >= space )
+      {
+      /* Line ends with dash */
+      nlines = roundint((length_total + space)/inc);
+      inc = length_total/(nlines - fspace);
+      factor = length_total + fspace*inc;
+      }
+   else
+      {
+      /* Line ends with space */
+      nlines = roundint(length_total/inc);
+      inc = length_total/nlines;
+      factor = length_total;
+      }
 
+
+   /* Interpolate and draw dashed line */
    j1 = 2;
    j2 = npoints - 1;
    for ( i=1; i<=nlines; i++ )
