@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * EventHandler.c
 *
@@ -22,7 +22,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include "gsegraf.h"
@@ -41,6 +41,7 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
           x1, x2, y1, y2, max_dimension,
           xtext1, xtext2, ytext1, ytext2;
    char label[21], string[51];
+   FILE *fptr;
    static GnomeCanvasItem *zoom_rectangle;
    GnomeCanvasItem *text, *rectangle;
 
@@ -74,18 +75,21 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
             FreeMemory();
             gtk_main_quit();
             }
+
          else if ( state == 0 && keyval == 65362 )
             {
             /* Up arrow */
             if ( flag_contour_labels == 1 )
                ViewLabelCallback(1);
             }
+
          else if ( state == 0 && keyval == 65364 )
             {
             /* Down arrow */
             if ( flag_contour_labels == 1 )
                ViewLabelCallback(-1);
             }
+
          break;
 
 
@@ -199,6 +203,7 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
             if ( flag == 1 )
                ViewCoordsDisplayHandler();
             }
+
          break;
 
       case GDK_MOTION_NOTIFY:
@@ -307,6 +312,7 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
                sprintf(string, "plot %d", icontour_plots);
             g_object_set(text_contour_data, "text", string, NULL);
             }
+
          break;
 
       case GDK_BUTTON_RELEASE:
@@ -352,16 +358,41 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
             if ( flag == 1 )
                ViewCoordsDisplayHandler();
             }
+
          break;
 
       case GDK_CONFIGURE:
          /* Draw graph first time */
          if ( p_window_data->flag == 1 )
             {
+            /* Draw graph */
             GetAxisLabelPixbufs();
             DrawGraph();
             p_window_data->flag = 2;
             flag_button1 = 0;
+
+            /* Save plot */
+            if ( save_filename != NULL )
+               FileOK(NULL);
+
+            /* Signal plot complete */
+            if ( p_tempfile != NULL )
+               {
+               if ( (fptr = fopen(p_tempfile, "w")) != NULL )
+                  {
+                  fprintf(fptr, "%s", "complete");
+                  fclose(fptr);
+                  }
+               }
+            /* printf("complete\n"); */
+
+            /* Close plot window */
+            if ( flag_close == 1 )
+               {
+               FreeMemory();
+               gtk_main_quit();
+               }
+
             break;
             }
 
