@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * Histogram.c
 *
@@ -22,7 +22,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <math.h>
@@ -39,7 +39,8 @@ void Histogram ( int iplot, int ihist )
           x1_box, y1_box, x2_box, y2_box,
           xmin, xmax, ymin, ymax, xscale, yscale,
           *yhist, x1_bar, y1_bar, x2_bar, y2_bar,
-          x1, y1, x2, y2;
+          x1, y1, x2, y2, xline;
+   GnomeCanvasPoints *points;
 
 
    /* Calculate data index */
@@ -86,7 +87,7 @@ void Histogram ( int iplot, int ihist )
 
 
    /* Calculate number of bins, binmin, and binmax */
-   index_bin_refs = (ihist - 1)*5;
+   index_bin_refs = (ihist - 1)*9;
    if ( strcmp(&bin_refs[index_bin_refs], "mean") == 0 )
       {
       n1 = ceil(((mean - binwidth/2.0) - data_min)/binwidth);
@@ -106,6 +107,13 @@ void Histogram ( int iplot, int ihist )
       else
          return;
       }
+   else if ( strcmp(&bin_refs[index_bin_refs], "integers") == 0 )
+      {
+      binwidth = 1.0;
+      nbins = roundint(data_max) - roundint(data_min) + 1.0;
+      binmin = (double) roundint(data_min) - 0.5;
+      binmax = (double) roundint(data_max) + 0.5;
+      }
 
 
    /* Calculate number of samples in each bin */
@@ -154,12 +162,10 @@ void Histogram ( int iplot, int ihist )
 
    /* Plot histogram */
    index_bin_values = (ihist - 1)*9;
+   points = gnome_canvas_points_new(2);
    for ( i=1; i<=nbins; i++ )
       {
-      x1_bar = binmin + (i - 1.0)/(nbins - 1.0)*(binmax - binwidth - binmin);
-      x2_bar = x1_bar + binwidth;
       y1_bar = 0.0;
-
       if ( strcmp(&bin_values[index_bin_values], "number") == 0 )
          y2_bar = yhist[i-1];
       else if ( strcmp(&bin_values[index_bin_values], "fraction") == 0 )
@@ -167,28 +173,53 @@ void Histogram ( int iplot, int ihist )
       else if ( strcmp(&bin_values[index_bin_values], "percent") == 0 )
          y2_bar = 100.0*yhist[i-1]/npts;
 
-      if ( x1_bar >= xmax || x2_bar <= xmin ||
-           y1_bar >= ymax || y2_bar <= ymin )
+      if ( y1_bar >= ymax || y2_bar <= ymin )
          continue;
-      if ( x1_bar < xmin )
-          x1_bar = xmin;
-      if ( x2_bar > xmax )
-          x2_bar = xmax;
       if ( y1_bar < ymin )
           y1_bar = ymin;
       if ( y2_bar > ymax )
           y2_bar = ymax;
 
-      x1 = x1_box + (x1_bar - xmin)*xscale;
       y1 = y2_box - (y1_bar - ymin)*yscale;
-      x2 = x1_box + (x2_bar - xmin)*xscale;
       y2 = y2_box - (y2_bar - ymin)*yscale;
 
-      DrawBar(x1+1.0, y1, x2-1.0, y2, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1]);
-      DrawBar(x1, y1+1.0, x2, y2-1.0, color_rgba[16], color_rgba[3]);
+      if ( stylechar1[iplot-1] == 'b' || stylechar1[iplot-1] == 'B' )
+         {
+         /* Draw bars */
+         x1_bar = binmin + (i - 1.0)/(nbins - 1.0)*(binmax - binwidth - binmin);
+         x2_bar = x1_bar + binwidth;
+
+         if ( x1_bar >= xmax || x2_bar <= xmin )
+            continue;
+         if ( x1_bar < xmin )
+             x1_bar = xmin;
+         if ( x2_bar > xmax )
+             x2_bar = xmax;
+
+         x1 = x1_box + (x1_bar - xmin)*xscale;
+         x2 = x1_box + (x2_bar - xmin)*xscale;
+
+         DrawBar(x1+1.0, y1, x2-1.0, y2, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1]);
+         DrawBar(x1, y1+1.0, x2, y2-1.0, color_rgba[16], color_rgba[3]);
+         }
+      else if ( stylechar1[iplot-1] == 'l' )
+         {
+         /* Draw lines */
+         xline = binmin + (i - 1.0)/(nbins - 1.0)*(binmax - binwidth - binmin) + binwidth/2.0;
+         if ( xmin < xline && xline < xmax )
+            {
+            points->coords[0] = x1_box + (xline - xmin)*xscale;
+            points->coords[1] = y1;
+            points->coords[2] = points->coords[0];
+            points->coords[3] = y2;
+            DrawLine(points, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+            }
+         }
       }
 
+   gnome_canvas_points_unref(points);
    free(yhist);
 
    return;
    }
+
