@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * InitializeVariables.c
 *
@@ -22,7 +22,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <math.h>
@@ -68,10 +68,6 @@ void InitializeVariables ( void )
    height_screen = gdk_screen_height();
 
 
-   /* Set menu-bar height */
-   /* height_menu_bar = 22; */
-
-
    /* Get date and time */
    memset(date_time, 0, sizeof(date_time));
    time_current = time(NULL);
@@ -115,10 +111,13 @@ void InitializeVariables ( void )
    bin_widths          = NULL;
    bin_values          = NULL;
    bin_refs            = NULL;
+   stemflags           = NULL;
+   stemvalues          = NULL;
    xlabel              = NULL;
    ylabel              = NULL;
    zlabel              = NULL;
    title               = NULL;
+   save_filename       = NULL;
    ndata               = NULL;
    xdata               = NULL;
    ydata               = NULL;
@@ -187,6 +186,7 @@ void InitializeVariables ( void )
 
    flag_coords_display = 0;
    flag_contour_labels = 0;
+   flag_close = 0;
 
 
    /* Specify default font name */
@@ -250,7 +250,7 @@ void InitializeVariables ( void )
    color_rgba[16] = 0x00000000;   /* x transparent            */
 
 
-   /********************************************************************************
+   /****************************************************************************
    *
    * Calculate all colors with maximum saturation from blue to green to red
    *    used for:
@@ -258,7 +258,7 @@ void InitializeVariables ( void )
    *       contour-line colors of 2d contour plots with plot_style = "auto"
    *       upper-surface colors of 3d mesh plots with plot_style = "auto"
    *
-   ********************************************************************************/
+   ****************************************************************************/
    n_color_spectrum_1 = 1021;
    color_spectrum_1[0] = 0x0000FFFF;                        /*               0x0000FFFF; index =           0 */
    for ( i=1; i<= 255; i++ )
@@ -271,12 +271,12 @@ void InitializeVariables ( void )
       color_spectrum_1[765+i] = 0xFFFF00FF - 0x10000*i;     /* 0xFFFE00FF to 0xFF0000FF; index = 766 to 1020 */
 
 
-   /********************************************************************************
+   /****************************************************************************
    *
    * Calculate all colors with 75% maximum saturation from blue to green to red
    *    used for lower-surface colors of 3d mesh plots with plot_style = "auto"
    *
-   ********************************************************************************/
+   ****************************************************************************/
    n_color_spectrum_2 = 769;
    color_spectrum_2[0] = 0x0000C0FF;                        /*               0x0000C0FF; index =          0 */
    for ( i=1; i<= 192; i++ )
