@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * PlotLines.c
 *
@@ -22,7 +22,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <math.h>
@@ -42,12 +42,12 @@ void PlotLines ( void )
           axis_length, *p, origin[3], Ry[9], Rz[9], Ryz[9], r1[3], r2[3], 
           line_coords[6] = { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
    char line[NLINE], *pchar, line_char, color_char;
-   extern char color_string[];    /* color-specification characters*/
+   extern char color_string[];   /* color-specification characters */
    const char *error_str[] =
-      { "Invalid line coordinates.",
-        "Invalid plot color for line.",
+      { "Invalid or missing line coordinates.",
+        "Invalid line color character.",
         "Invalid or missing line or color specification.",
-        "Invalid plot symbol for line." };
+        "Invalid line character." };
    FILE *fptr;
    GnomeCanvasPoints *points;
 
@@ -271,7 +271,7 @@ void PlotLines ( void )
          {
          if ( ncoords == 4 )
             {
-            if ( sscanf(line, "%*s %lf %lf %lf %lf",
+            if ( sscanf(&line[11], " %lf %lf %lf %lf",
                         &line_coords[0], &line_coords[2],
                         &line_coords[1], &line_coords[3]) != 4 )
                {
@@ -283,7 +283,7 @@ void PlotLines ( void )
 
          else if ( ncoords == 6 )
             {
-            if ( sscanf(line, "%*s %lf %lf %lf %lf %lf %lf",
+            if ( sscanf(&line[11], " %lf %lf %lf %lf %lf %lf",
                         &line_coords[0], &line_coords[3],
                         &line_coords[1], &line_coords[4],
                         &line_coords[2], &line_coords[5]) != 6 )
@@ -316,11 +316,11 @@ void PlotLines ( void )
          if ( fgets(line, sizeof(line), fptr) != NULL )
             if ( strncmp(line, "line_style", 10) == 0 )
                {
-               if ( sscanf(line, "%*s %c 0x%x", &line_char, (unsigned int *) &line_color) == 2 ||
-                    sscanf(line, "%*s %c 0X%x", &line_char, (unsigned int *) &line_color) == 2 )
-                  sscanf(line, "%*s %*c %*s %u", &line_width);
+               if ( sscanf(&line[10], " %c 0x%x", &line_char, (unsigned int *) &line_color) == 2 ||
+                    sscanf(&line[10], " %c 0X%x", &line_char, (unsigned int *) &line_color) == 2 )
+                  sscanf(&line[10], " %*c %*s %u", &line_width);
 
-               else if ( sscanf(line, "%*s %c %c", &line_char, &color_char) == 2 )
+               else if ( sscanf(&line[10], " %c %c", &line_char, &color_char) == 2 )
                   {
                   if ( (pchar = strchr(color_string, color_char)) == NULL )
                      {
@@ -353,7 +353,7 @@ void PlotLines ( void )
                   }
                }
 
-         /* Draw lines */
+         /* Draw line */
          if ( line_char == 'l' )
             {
             if ( strcmp(p_plot_param->axis_type, "linear")    == 0 ||
@@ -418,8 +418,7 @@ void PlotLines ( void )
                }
             }
 
-
-         /* Draw dashed lines */
+         /* Draw dashed line */
          else if ( line_char == 'd' )
             {
             if ( strcmp(p_plot_param->axis_type, "linear")    == 0 ||
