@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * PolarPlot.c
 *
@@ -22,7 +22,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <math.h>
@@ -33,11 +33,11 @@
 void PolarPlot ( void )
    {
    /* Declare variables */
-   int i, nyvalues, nrvalues, iplot, nplots, npts, index, anchor,
-       window_width, window_height;
+   int i, nyvalues, nrvalues, iplot, nplots, npts, index, index_stemflags,
+       anchor, window_width, window_height;
    double rmin, rmax, xorigin, yorigin, radius, radius_grid, rscale,
           x, y, x1, y1, x2, y2, xtext1, xtext2, ytext1, ytext2,
-          theta, theta_max, r, width_xtick_label;
+          theta, theta_max, r, r1, width_xtick_label;
    char tick_label[4];
    GnomeCanvasPoints *points;
    GnomeCanvasItem *line, *circle, *rectangle, *text, *pixbuf_item;
@@ -175,8 +175,8 @@ void PolarPlot ( void )
       for ( i=1; i<=12; i++ )
          {
          theta = (i - 1.0)*30.0*deg2rad;
-         x1 = xorigin + (radius + 8.0)*cos(theta);
-         y1 = yorigin - (radius + 8.0)*sin(theta);
+         x = xorigin + (radius + 8.0)*cos(theta);
+         y = yorigin - (radius + 8.0)*sin(theta);
          sprintf(tick_label, "%d", (i - 1)*30);
 
          if ( i == 1 )
@@ -199,8 +199,8 @@ void PolarPlot ( void )
          text = gnome_canvas_item_new(group,
                                       GNOME_TYPE_CANVAS_TEXT,
                                       "text", tick_label,
-                                      "x", x1,
-                                      "y", y1,
+                                      "x", x,
+                                      "y", y,
                                       "anchor", anchor,
                                       "font-desc", font_tick_labels,
                                       "fill_color_rgba", 0x000000FF,
@@ -332,6 +332,53 @@ void PolarPlot ( void )
       {
       npts = ndata[iplot-1];
 
+      /* Draw stem lines */
+      index_stemflags = (iplot - 1)*4;
+      if ( strcmp(&stemflags[index_stemflags],  "on") == 0 ||
+           strcmp(&stemflags[index_stemflags], "num") == 0 )
+         {
+         points = gnome_canvas_points_new(2);
+
+         /* Calculate r coordinate of stem point 1 */
+         if ( strcmp(&stemflags[index_stemflags], "on") == 0 )
+            r1 = rmin;
+         else if ( strcmp(&stemflags[index_stemflags], "num") == 0 )
+            {
+            if ( rmin <= stemvalues[iplot-1] && stemvalues[iplot-1] <= rmax )
+               r1 = stemvalues[iplot-1];
+            else if ( stemvalues[iplot-1] < rmin )
+               r1 = rmin;
+            else if ( stemvalues[iplot-1] > rmax )
+               r1 = rmax;
+            }
+
+         for ( i=1; i<=npts; i++ )
+            {
+            theta = xdata[index+i-1];
+            r     = ydata[index+i-1];
+            if ( r <= rmax )
+               {
+               /* Calculate coordinates of stem point 1 */
+               x = xorigin + (r1 - rmin)*cos(theta)*rscale;
+               y = yorigin - (r1 - rmin)*sin(theta)*rscale;
+               points->coords[0] = x;
+               points->coords[1] = y;
+
+               /* Calculate coordinates of stem point 2 */
+               if ( r < rmin )
+                  r = rmin;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
+               points->coords[2] = x;
+               points->coords[3] = y;
+               DrawLine(points, outline_colors_rgba[iplot-1], 1);
+               }
+            }
+
+         gnome_canvas_points_unref(points);
+         }
+
+
       /* Draw lines */
       if ( stylechar1[iplot-1] == 'l' )
          DrawLineSegmentsPolar(iplot, index, npts, xorigin, yorigin, rmin, rmax, rscale, 'l');
@@ -351,10 +398,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawCircle(x1, y1, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+               DrawCircle(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
                           stylesizes[iplot-1]);
                }
             }
@@ -370,10 +417,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawTriangle(x1, y1, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+               DrawTriangle(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
                             stylesizes[iplot-1]);
                }
             }
@@ -389,10 +436,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawSquare(x1, y1, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+               DrawSquare(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
                           stylesizes[iplot-1]);
                }
             }
@@ -408,10 +455,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawDiamond(x1, y1, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+               DrawDiamond(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
                            stylesizes[iplot-1]);
                }
             }
@@ -427,10 +474,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawPentagon(x1, y1, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+               DrawPentagon(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
                             stylesizes[iplot-1]);
                }
             }
@@ -446,10 +493,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawHexagon(x1, y1, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+               DrawHexagon(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
                            stylesizes[iplot-1]);
                }
             }
@@ -465,10 +512,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawPlus(x1, y1, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+               DrawPlus(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
                }
             }
          }
@@ -483,10 +530,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawX(x1, y1, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+               DrawX(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
                }
             }
          }
@@ -501,10 +548,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawStar(x1, y1, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+               DrawStar(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
                }
             }
          }
@@ -519,10 +566,10 @@ void PolarPlot ( void )
             r     = ydata[index+i-1];
             if ( rmin <= r && r <= rmax )
                {
-               x1 = xorigin + (r - rmin)*cos(theta)*rscale;
-               y1 = yorigin - (r - rmin)*sin(theta)*rscale;
+               x = xorigin + (r - rmin)*cos(theta)*rscale;
+               y = yorigin - (r - rmin)*sin(theta)*rscale;
 
-               DrawAsterisk(x1, y1, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+               DrawAsterisk(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
                }
             }
          }
@@ -544,16 +591,16 @@ void PolarPlot ( void )
       for ( i=1; i<=nrvalues; i++ )
          {
          theta = 45.0*deg2rad;
-         x1 = xorigin + (p_ticklabels->yvalues[i-1] - rmin)*rscale*cos(theta);
-         y1 = yorigin - (p_ticklabels->yvalues[i-1] - rmin)*rscale*sin(theta);
+         x = xorigin + (p_ticklabels->yvalues[i-1] - rmin)*rscale*cos(theta);
+         y = yorigin - (p_ticklabels->yvalues[i-1] - rmin)*rscale*sin(theta);
 
          sprintf(tick_label, "%g", p_ticklabels->yvalues[i-1]);
 
          text = gnome_canvas_item_new(group,
                                       GNOME_TYPE_CANVAS_TEXT,
                                       "text", tick_label,
-                                      "x", x1,
-                                      "y", y1,
+                                      "x", x,
+                                      "y", y,
                                       "anchor", GTK_ANCHOR_NORTH_EAST,
                                       "font-desc", font_tick_labels,
                                       "fill_color_rgba", 0x000000FF,
