@@ -22,7 +22,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <ctype.h>
@@ -35,7 +35,8 @@ void ReadParamFile ( void )
    /* Declare variables */
    int i, j, iplot, nplots, iformat, nformat, nfilenames_total, nformats_total,
        index_filenames, index_formats, index_plot_types, index_bin_values,
-       index_bin_refs, ibinwidth, ibinvalue, ibinref, stylesize;
+       index_bin_refs, ibinwidth, index_stemflags, ibinvalue, ibinref, istemflag,
+       stylesize;
    unsigned int index, size;
    char line[NLINE], *string, *pchar, character;
    extern char color_string[];   /* color-specification characters */
@@ -188,7 +189,9 @@ void ReadParamFile ( void )
    outline_colors_rgba = malloc(nplots*sizeof(guint32));
    bin_widths          = malloc(nplots*sizeof(double));
    bin_values          = malloc(9*nplots*sizeof(char));
-   bin_refs            = malloc(5*nplots*sizeof(char));
+   bin_refs            = malloc(9*nplots*sizeof(char));
+   stemflags           = malloc(4*nplots*sizeof(char));
+   stemvalues          = malloc(nplots*sizeof(double));
    ndata               = malloc(nplots*sizeof(int));
    memset(filenames,   0, nfilenames_total*sizeof(char));
    memset(formats,     0, nformats_total*sizeof(char));
@@ -197,7 +200,8 @@ void ReadParamFile ( void )
    memset(stylechar1,  0, nplots*sizeof(char));
    memset(stylechar2,  0, nplots*sizeof(char));
    memset(bin_values,  0, 9*nplots*sizeof(char));
-   memset(bin_refs,    0, 5*nplots*sizeof(char));
+   memset(bin_refs,    0, 9*nplots*sizeof(char));
+   memset(stemflags,   0, 4*nplots*sizeof(char));
 
 
    /* Set default style parameters */
@@ -218,7 +222,15 @@ void ReadParamFile ( void )
       {
       bin_widths[i-1] = -1.0;
       strcpy(&bin_values[(i-1)*9], "percent");
-      strcpy(&bin_refs[(i-1)*5], "mean");
+      strcpy(&bin_refs[(i-1)*9], "mean");
+      }
+
+
+   /* Set default stem flags and stem values */
+   for ( i=1; i<=nplots; i++ )
+      {
+      strcpy(&stemflags[(i-1)*4], "off");
+      stemvalues[i-1] = 0.0;   /* not used */
       }
 
 
@@ -334,9 +346,9 @@ void ReadParamFile ( void )
       {
       if ( strcmp(&plot_types[index_plot_types], "points")    != 0 &&
            strcmp(&plot_types[index_plot_types], "histogram") != 0 &&
-           strcmp(&plot_types[index_plot_types], "mesh")      != 0 &&
+           strcmp(&plot_types[index_plot_types], "color")     != 0 &&
            strcmp(&plot_types[index_plot_types], "contour")   != 0 &&
-           strcmp(&plot_types[index_plot_types], "color")     != 0 )
+           strcmp(&plot_types[index_plot_types], "mesh")      != 0 )
          {
          ErrorDialog(error_str[3]);
          FreeMemory();
@@ -350,6 +362,7 @@ void ReadParamFile ( void )
 
    /* Read plot styles */
    iplot = 0;
+   index_plot_types = 0;
    rewind(fptr);
    if ( nplots > 0 )
       {
@@ -358,209 +371,213 @@ void ReadParamFile ( void )
          if ( strncmp(line, "plot_style", 10) == 0 )
             {
             iplot++;
-            size = strlen(&line[10]);
-            if ( (string = get_string(&line[10], &size)) != NULL )
+
+            if ( strcmp(&plot_types[index_plot_types], "points")    == 0 ||
+                 strcmp(&plot_types[index_plot_types], "histogram") == 0 )
                {
-               if ( strcmp(string, "nearest") == 0 )
+               if ( (sscanf(&line[10], " %c 0x%x", &stylechar1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
+                     sscanf(&line[10], " %c 0X%x", &stylechar1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2) &&
+                    isdigit(stylechar1[iplot-1]) == 0 )
                   {
-                  /************************************************
+                  /************************************************************
+                  *
+                  * 2d points and 3d points plot types
+                  * Read symbol character, hexadecimal color, and symbol size
+                  *
+                  * 2d histogram
+                  * Read symbol character and hexadecimal color
+                  *
+                  ************************************************************/
+                  styleflags[iplot-1] = 4;
+                  fill_colors_rgba[iplot-1]    = stylecolor2[iplot-1];         /* set specified fill color */
+                  outline_colors_rgba[iplot-1] = stylecolor2[iplot-1];         /* set specified outline color */
+                  if ( (pchar = strchr("ctsiphb", stylechar1[iplot-1])) != NULL )
+                     fill_colors_rgba[iplot-1] = color_rgba[3];                /* set fill color white */
+                  if ( (pchar = strchr("cCtTsSiIpPhH+xra", stylechar1[iplot-1])) != NULL )
+                     stylesizes[iplot-1] = 6;                                  /* set default symbol size */
+                  if ( sscanf(&line[10], " %*c %*s %d", &stylesize) == 1 )
+                     stylesizes[iplot-1] = abs(stylesize);                     /* get symbol size */
+                  }
+
+               else if ( sscanf(&line[10], " %c %c", &stylechar1[iplot-1], &stylechar2[iplot-1]) == 2 &&
+                         (pchar = strchr(color_string, stylechar2[iplot-1])) != NULL )
+                  {
+                  /************************************************************
+                  *
+                  * 2d points and 3d points plot types
+                  * Read symbol character, color character, and symbol size
+                  *
+                  * 2d histogram
+                  * Read symbol character and color character
+                  *
+                  ************************************************************/
+                  styleflags[iplot-1] = 2;
+                  index = pchar - &color_string[0];                            /* get index to color character */
+                  stylecolor2[iplot-1] = color_rgba[index];                    /* set specified color */
+                  fill_colors_rgba[iplot-1]    = stylecolor2[iplot-1];         /* set specified fill color */
+                  outline_colors_rgba[iplot-1] = stylecolor2[iplot-1];         /* set specified outline color */
+                  if ( (pchar = strchr("ctsiphb", stylechar1[iplot-1])) != NULL )
+                     fill_colors_rgba[iplot-1] = color_rgba[3];                /* set fill color white */
+                  if ( (pchar = strchr("cCtTsSiIpPhH+xra", stylechar1[iplot-1])) != NULL )
+                     stylesizes[iplot-1] = 6;                                  /* set default symbol size */
+                  if ( sscanf(&line[10], " %*c %*c %d", &stylesize) == 1 )
+                     stylesizes[iplot-1] = abs(stylesize);                     /* get symbol size */
+                  }
+               }
+
+            else if ( strcmp(&plot_types[index_plot_types], "color") == 0 )
+               {
+               size = strlen(&line[10]);
+               if ( (string = get_string(&line[10], &size)) != NULL )
+                  {
+                  /************************************************************
                   *
                   * 2d color plot type
-                  * Read "nearest" string and two decimal numbers
+                  * Read "nearest" or "bilinear" string and two decimal numbers
                   *
-                  ************************************************/
-                  styleflags[iplot-1] = 9;                                          /* set style flag */
-                  sscanf(&string[size+1], " %lf %lf", &zblack[iplot-1], &zwhite[iplot-1]);
+                  ************************************************************/
+                  if ( strcmp(string, "nearest") == 0 )
+                     {
+                     styleflags[iplot-1] = 9;
+                     sscanf(&string[size+1], " %lf %lf", &zblack[iplot-1], &zwhite[iplot-1]);
+                     }
+                  else if ( strcmp(string, "bilinear") == 0 )
+                     {
+                     styleflags[iplot-1] = 8;
+                     sscanf(&string[size+1], " %lf %lf", &zblack[iplot-1], &zwhite[iplot-1]);
+                     }
                   }
-               else if ( strcmp(string, "bilinear") == 0 )
+               }
+
+            else if ( strcmp(&plot_types[index_plot_types], "contour") == 0 &&
+                      strcmp(p_plot_param->axis_type, "linear") == 0 )
+               {
+               size = strlen(&line[10]);
+               if ( (string = get_string(&line[10], &size)) != NULL )
                   {
-                  /*************************************************
-                  *
-                  * 2d color plot type
-                  * Read "bilinear" string and two decimal numbers
-                  *
-                  *************************************************/
-                  styleflags[iplot-1] = 8;                                          /* set style flag */
-                  sscanf(&string[size+1], " %lf %lf", &zblack[iplot-1], &zwhite[iplot-1]);
-                  }
-               else if ( strcmp(string, "auto") == 0 )
-                  {
-                  /*******************************************
+                  /************************************************************
                   *
                   * 2d contour plot type
                   * Read "auto" string and line width
                   *
+                  ************************************************************/
+                  if ( strcmp(string, "auto") == 0 )
+                     {
+                     styleflags[iplot-1] = 7;
+                     if ( sscanf(&string[size+1], " %d", &stylesize) == 1 )
+                        stylesizes[iplot-1] = abs(stylesize);                  /* get line width */
+                     }
+                  }
+
+               else if ( sscanf(&line[10], " 0x%x", (unsigned int *) &stylecolor1[iplot-1]) == 1 ||
+                         sscanf(&line[10], " 0X%x", (unsigned int *) &stylecolor1[iplot-1]) == 1 )
+                  {
+                  /************************************************************
+                  *
+                  * 2d contour plot type
+                  * Read hexadecimal color and line width
+                  *
+                  ************************************************************/
+                  styleflags[iplot-1] = 3;
+                  if ( sscanf(&line[10], " %*s %d", &stylesize) == 1 )
+                     stylesizes[iplot-1] = abs(stylesize);                     /* get line width */
+                  }
+
+               else if ( sscanf(&line[10], " %c", &stylechar1[iplot-1]) == 1 &&
+                         (pchar = strchr(color_string, stylechar1[iplot-1])) != NULL )
+                  {
+                  /************************************************************
+                  *
+                  * 2d contour plot type
+                  * Read color character and line width
+                  *
+                  ************************************************************/
+                  styleflags[iplot-1] = 1;
+                  index = pchar - &color_string[0];                            /* get index to color character */
+                  stylecolor1[iplot-1] = color_rgba[index];                    /* set specified color */
+                  if ( sscanf(&line[10], " %*c %d", &stylesize) == 1 )
+                     stylesizes[iplot-1] = abs(stylesize);                     /* get line width */
+                  }
+               }
+
+            else if ( (strcmp(&plot_types[index_plot_types], "contour") == 0 ||
+                       strcmp(&plot_types[index_plot_types], "mesh")    == 0) &&
+                      strcmp(p_plot_param->axis_type, "3d") == 0 )
+               {
+               size = strlen(&line[10]);
+               if ( strcmp(&plot_types[index_plot_types], "mesh") == 0 &&
+                    (string = get_string(&line[10], &size)) != NULL )
+                  {
+                  /************************************************************
+                  *
                   * 3d mesh plot type
                   * Read "auto" string and color alpha value
                   *
-                  *******************************************/
-                  styleflags[iplot-1] = 7;                                          /* set style flag */
-                  if ( sscanf(&string[size+1], " 0x%x", (unsigned int *) &alphacolor[iplot-1]) == 1 ||
-                       sscanf(&string[size+1], " 0X%x", (unsigned int *) &alphacolor[iplot-1]) == 1 )
+                  ************************************************************/
+                  if ( strcmp(string, "auto") == 0 )
                      {
-                     if ( alphacolor[iplot-1] > 0xFF )                              /* check alpha value */
-                        alphacolor[iplot-1] = 0xFF;
-                     }
-                  else if ( sscanf(&string[size+1], " %d", &stylesize) == 1 )
-                     {
-                     stylesizes[iplot-1] = abs(stylesize);                          /* get line width */
+                     styleflags[iplot-1] = 7;
+                     if ( sscanf(&string[size+1], " 0x%x", (unsigned int *) &alphacolor[iplot-1]) == 1 ||
+                          sscanf(&string[size+1], " 0X%x", (unsigned int *) &alphacolor[iplot-1]) == 1 )
+                        {
+                        if ( alphacolor[iplot-1] > 0xFF )                      /* check alpha value */
+                           alphacolor[iplot-1] = 0xFF;
+                        }
                      }
                   }
-               }
 
-            else if ( sscanf(&line[10], " 0x%x 0x%x", (unsigned int *) &stylecolor1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
-                      sscanf(&line[10], " 0X%x 0X%x", (unsigned int *) &stylecolor1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
-                      sscanf(&line[10], " 0x%x 0X%x", (unsigned int *) &stylecolor1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
-                      sscanf(&line[10], " 0X%x 0x%x", (unsigned int *) &stylecolor1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 )
-               {
-               /************************************
-               *
-               * 3d contour and 3d mesh plot types
-               * Read two hexadecimal colors
-               *
-               ************************************/
-               styleflags[iplot-1] = 6;                                             /* set style flag */
-               }
+               else if ( sscanf(&line[10], " 0x%x 0x%x", (unsigned int *) &stylecolor1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
+                         sscanf(&line[10], " 0X%x 0X%x", (unsigned int *) &stylecolor1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
+                         sscanf(&line[10], " 0x%x 0X%x", (unsigned int *) &stylecolor1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
+                         sscanf(&line[10], " 0X%x 0x%x", (unsigned int *) &stylecolor1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 )
+                  {
+                  /************************************************************
+                  *
+                  * 3d contour and 3d mesh plot types
+                  * Read two hexadecimal colors
+                  *
+                  ************************************************************/
+                  styleflags[iplot-1] = 6;
+                  }
 
-            else if ( (sscanf(&line[10], " 0x%x %c", (unsigned int *) &stylecolor1[iplot-1], &stylechar2[iplot-1]) == 2 ||
-                       sscanf(&line[10], " 0X%x %c", (unsigned int *) &stylecolor1[iplot-1], &stylechar2[iplot-1]) == 2) &&
-                      isdigit(stylechar2[iplot-1]) == 0 )
-               {
-               /*********************************************
-               *
-               * 3d contour and 3d mesh plot types
-               * Read hexadecimal color and color character
-               *
-               *********************************************/
-               styleflags[iplot-1] = 5;                                             /* set style flag */
-               if ( (pchar = strchr(color_string, stylechar2[iplot-1])) != NULL )   /* get pointer to color character 2 */
+               else if ( sscanf(&line[10], " 0x%x %c", (unsigned int *) &stylecolor1[iplot-1], &stylechar2[iplot-1]) == 2 ||
+                         sscanf(&line[10], " 0X%x %c", (unsigned int *) &stylecolor1[iplot-1], &stylechar2[iplot-1]) == 2 )
                   {
-                  index = pchar - &color_string[0];                                 /* get index to color character 2 */
+                  /************************************************************
+                  *
+                  * 3d contour and 3d mesh plot types
+                  * Read hexadecimal color and color character
+                  *
+                  ************************************************************/
+                  styleflags[iplot-1] = 5;
                   }
-               stylecolor2[iplot-1] = color_rgba[index];                            /* set specified color */
-               }
 
-            else if ( (sscanf(&line[10], " %c 0x%x", &stylechar1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
-                       sscanf(&line[10], " %c 0X%x", &stylechar1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2) &&
-                      isdigit(stylechar1[iplot-1]) == 0 )
-               {
-               /************************************************************
-               *
-               * 2d points and 3d points plot types
-               * Read symbol character, hexadecimal color, and symbol size
-               *
-               * 2d histogram
-               * Read symbol character and hexadecimal color
-               *
-               * 3d contour and 3d mesh plot types
-               * Read color character and hexadecimal color
-               *
-               ************************************************************/
-               styleflags[iplot-1] = 4;                                             /* set style flag */
-               fill_colors_rgba[iplot-1]    = stylecolor2[iplot-1];                 /* set specified fill color */
-               outline_colors_rgba[iplot-1] = stylecolor2[iplot-1];                 /* set specified outline color */
-               if ( stylechar1[iplot-1] == 'c' ||
-                    stylechar1[iplot-1] == 't' ||
-                    stylechar1[iplot-1] == 's' ||
-                    stylechar1[iplot-1] == 'i' ||
-                    stylechar1[iplot-1] == 'p' ||
-                    stylechar1[iplot-1] == 'h' ||
-                    stylechar1[iplot-1] == 'b' )
+               else if ( sscanf(&line[10], " %c 0x%x", &stylechar1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 ||
+                         sscanf(&line[10], " %c 0X%x", &stylechar1[iplot-1], (unsigned int *) &stylecolor2[iplot-1]) == 2 )
                   {
-                  fill_colors_rgba[iplot-1] = color_rgba[3];                        /* set fill color white */
+                  /************************************************************
+                  *
+                  * 3d contour and 3d mesh plot types
+                  * Read color character and hexadecimal color
+                  *
+                  ************************************************************/
+                  styleflags[iplot-1] = 4;
                   }
-               if ( (pchar = strchr("cCtTsSiIpPhH+xra", stylechar1[iplot-1])) != NULL )
+
+               else if ( sscanf(&line[10], " %c %c", &stylechar1[iplot-1], &stylechar2[iplot-1]) == 2 )
                   {
-                  stylesizes[iplot-1] = 6;                                          /* set default symbol size */
-                  }
-               if ( sscanf(&line[10], " %*c %*s %d", &stylesize) == 1 )
-                  {
-                  stylesizes[iplot-1] = abs(stylesize);                             /* get line width */
+                  /************************************************************
+                  *
+                  * 3d contour and 3d mesh plot types
+                  * Read two color characters
+                  *
+                  ************************************************************/
+                  styleflags[iplot-1] = 2;
                   }
                }
 
-            else if ( sscanf(&line[10], " 0x%x", (unsigned int *) &stylecolor1[iplot-1]) == 1 ||
-                      sscanf(&line[10], " 0X%x", (unsigned int *) &stylecolor1[iplot-1]) == 1 )
-               {
-               /****************************************
-               *
-               * 2d contour plot type
-               * Read hexadecimal color and line width
-               *
-               ****************************************/
-               styleflags[iplot-1] = 3;                                             /* set style flag */
-               if ( sscanf(&line[10], " %*s %d", &stylesize) == 1 )
-                  {
-                  stylesizes[iplot-1] = abs(stylesize);                             /* get line width */
-                  }
-               }
-
-            else if ( sscanf(&line[10], " %c %c", &stylechar1[iplot-1], &stylechar2[iplot-1]) == 2 &&
-                      (pchar = strchr(color_string, stylechar2[iplot-1])) != NULL )
-               {
-               /**********************************************************
-               *
-               * 2d points, 2d histogram, 3d points plot types
-               * Read symbol character, color character, and symbol size
-               *
-               * 3d contour and 3d mesh plot types
-               * Read two color characters
-               *
-               **********************************************************/
-               styleflags[iplot-1] = 2;                                             /* set style flag */
-               index = pchar - &color_string[0];                                    /* get index to color character */
-               stylecolor2[iplot-1] = color_rgba[index];                            /* set specified color */
-               fill_colors_rgba[iplot-1]    = stylecolor2[iplot-1];                 /* set specified fill color */
-               outline_colors_rgba[iplot-1] = stylecolor2[iplot-1];                 /* set specified outline color */
-               if ( stylechar1[iplot-1] == 'c' ||
-                    stylechar1[iplot-1] == 't' ||
-                    stylechar1[iplot-1] == 's' ||
-                    stylechar1[iplot-1] == 'i' ||
-                    stylechar1[iplot-1] == 'p' ||
-                    stylechar1[iplot-1] == 'h' ||
-                    stylechar1[iplot-1] == 'b' )
-                  {
-                  fill_colors_rgba[iplot-1] = color_rgba[3];                        /* set fill color white */
-                  }
-               if ( (pchar = strchr("cCtTsSiIpPhH+xra", stylechar1[iplot-1])) != NULL )
-                  {
-                  stylesizes[iplot-1] = 6;                                          /* set default symbol size */
-                  }
-               if ( sscanf(&line[10], " %*c %*c %d", &stylesize) == 1 )
-                  {
-                  stylesizes[iplot-1] = abs(stylesize);                             /* get line width */
-                  }
-               }
-
-            else if ( sscanf(&line[10], " %c", &stylechar1[iplot-1]) == 1 &&
-                      (pchar = strchr(color_string, stylechar1[iplot-1])) != NULL )
-               {
-               /**************************************
-               *
-               * 2d contour plot type
-               * Read color character and line width
-               *
-               **************************************/
-               styleflags[iplot-1] = 1;                                             /* set style flag */
-               index = pchar - &color_string[0];                                    /* get index to color character */
-               stylecolor1[iplot-1] = color_rgba[index];                            /* set specified color */
-               if ( sscanf(&line[10], " %*c %d", &stylesize) == 1 )
-                  {
-                  stylesizes[iplot-1] = abs(stylesize);                             /* get line width */
-                  }
-               }
-
-            else
-               {
-               /**************************************
-               *
-               * Invalid plot_style parameter.
-               *
-               **************************************/
-               ErrorDialog(error_str[4]);
-               FreeMemory();
-               exit(1);
-               }
+            /* Increment index */
+            index_plot_types = index_plot_types + 10;
             }
 
          else if ( strncmp(line, "#####", 5) == 0 )
@@ -573,8 +590,10 @@ void ReadParamFile ( void )
    ibinwidth = 0;
    ibinvalue = 0;
    ibinref   = 0;
+   istemflag = 0;
    index_bin_values = 0;
    index_bin_refs   = 0;
+   index_stemflags  = 0;
    rewind(fptr);
    while ( fgets(line, sizeof(line), fptr) != NULL )
       {
@@ -596,7 +615,6 @@ void ReadParamFile ( void )
 
             if ( sscanf(&line[i], "%lf", &p_plot_param->axis_limits[j-1]) == 1 )
                axis_limits[j-1] = 1;
-
             else if ( sscanf(&line[i], " %c", &character ) == 1 )
                {
                if ( character == '#' )
@@ -616,6 +634,44 @@ void ReadParamFile ( void )
             }
          }
 
+      else if ( strncmp(line, "view3d", 6) == 0 )
+         {
+         if ( sscanf(&line[6], "%lf %lf", &p_plot_param_3d->phi, &p_plot_param_3d->theta) != 2 )
+            {
+            ErrorDialog(error_str[7]);
+            FreeMemory();
+            exit(1);
+            }
+         }
+
+      else if ( strncmp(line, "grid", 4) == 0 )
+         {
+         size = strlen(&line[4]);
+         if ( (string = get_string(&line[4], &size)) != NULL &&
+              strcmp(string, "off") == 0 )
+            {
+            strncpy(&p_plot_param->grid[0], string, 3);
+            }
+         else if ( sscanf(&line[4], " %c 0x%x", &gridchar1, &gridcolor) == 2 ||
+                   sscanf(&line[4], " %c 0X%x", &gridchar1, &gridcolor) == 2 )
+            {
+            strcpy(&p_plot_param->grid[0], "on2");
+            }
+         else if ( sscanf(&line[4], " %c %c", &gridchar1, &gridchar2) == 2 &&
+                   (pchar = strchr(color_string, gridchar2)) != NULL )
+            {
+            index = pchar - &color_string[0];   /* get index to color character */
+            gridcolor = color_rgba[index];      /* set specified color */
+            strcpy(&p_plot_param->grid[0], "on1");
+            }
+         else
+            {
+            ErrorDialog(error_str[6]);
+            FreeMemory();
+            exit(1);
+            }
+         }
+
       else if ( strncmp(line, "xlabel", 6) == 0 )
          {
          size = strlen(&line[6]);
@@ -656,44 +712,6 @@ void ReadParamFile ( void )
             }
          }
 
-      else if ( strncmp(line, "grid", 4) == 0 )
-         {
-         size = strlen(&line[4]);
-         if ( (string = get_string(&line[4], &size)) != NULL &&
-              strcmp(string, "off") == 0 )
-            {
-            strncpy(&p_plot_param->grid[0], string, 3);
-            }
-         else if ( sscanf(&line[4], " %c 0x%x", &gridchar1, &gridcolor) == 2 ||
-                   sscanf(&line[4], " %c 0X%x", &gridchar1, &gridcolor) == 2 )
-            {
-            strcpy(&p_plot_param->grid[0], "on2");
-            }
-         else if ( sscanf(&line[4], " %c %c", &gridchar1, &gridchar2) == 2 &&
-                   (pchar = strchr(color_string, gridchar2)) != NULL )
-            {
-            index = pchar - &color_string[0];   /* get index to color character */
-            gridcolor = color_rgba[index];      /* set specified color */
-            strcpy(&p_plot_param->grid[0], "on1");
-            }
-         else
-            {
-            ErrorDialog(error_str[6]);
-            FreeMemory();
-            exit(1);
-            }
-         }
-
-      else if ( strncmp(line, "view3d", 6) == 0 )
-         {
-         if ( sscanf(&line[6], "%lf %lf", &p_plot_param_3d->phi, &p_plot_param_3d->theta) != 2 )
-            {
-            ErrorDialog(error_str[7]);
-            FreeMemory();
-            exit(1);
-            }
-         }
-
       else if ( strncmp(line, "bin_width", 9) == 0 )
          {
          ibinwidth++;
@@ -728,8 +746,8 @@ void ReadParamFile ( void )
             size = strlen(&line[7]);
             if ( (string = get_string(&line[7], &size)) != NULL )
                {
-               strncpy(&bin_refs[index_bin_refs], string, 4);
-               index_bin_refs = index_bin_refs + 5;
+               strncpy(&bin_refs[index_bin_refs], string, 8);
+               index_bin_refs = index_bin_refs + 9;
                }
             }
          }
@@ -744,6 +762,36 @@ void ReadParamFile ( void )
             }
          }
 
+      else if ( strncmp(line, "stems", 5) == 0 )
+         {
+         istemflag++;
+         if ( istemflag <= nplots )
+            {
+            if ( sscanf(&line[5], "%lf", &stemvalues[istemflag-1]) == 1 )
+               {
+               strcpy(&stemflags[index_stemflags], "num");
+               if ( strcmp(p_plot_param->axis_type, "semilogy") == 0 ||
+                    strcmp(p_plot_param->axis_type, "loglog")   == 0 )
+                  {
+                  if ( stemvalues[istemflag-1] != 0.0 )
+                     stemvalues[istemflag-1] = log10(fabs(stemvalues[istemflag-1]));
+                  else
+                     stemvalues[istemflag-1] = log10(DBL_MIN);
+                  }
+               index_stemflags = index_stemflags + 4;
+               }
+            else
+               {
+               size = strlen(&line[5]);
+               if ( (string = get_string(&line[5], &size)) != NULL )
+                  {
+                  strncpy(&stemflags[index_stemflags], string, 3);
+                  index_stemflags = index_stemflags + 4;
+                  }
+               }
+            }
+         }
+
       else if ( strncmp(line, "date_time", 9) == 0 )
          {
          size = strlen(&line[9]);
@@ -751,6 +799,27 @@ void ReadParamFile ( void )
             strncpy(&p_plot_param->date_time_anchor[0], string, 9);
          }
 
+      else if ( strncmp(line, "save_close", 10) == 0 )
+         {
+         size = strlen(&line[10]);
+         if ( (string = get_string(&line[10], &size)) != NULL )
+            {
+            save_filename = malloc(size + 1);
+            strcpy(save_filename, string);
+            flag_close = 1;
+            }
+         }
+
+      else if ( strncmp(line, "save", 4) == 0 )
+         {
+         size = strlen(&line[4]);
+         if ( (string = get_string(&line[4], &size)) != NULL )
+            {
+            save_filename = malloc(size + 1);
+            strcpy(save_filename, string);
+            }
+         }
+
       else if ( strncmp(line, "plot_box", 8) == 0 )
          {
          size = strlen(&line[8]);
