@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * ViewMenu.c
 *
@@ -32,7 +32,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <math.h>
@@ -308,6 +308,11 @@ void ViewAxesCallback ( GtkEntry *entry_box )
          DrawGrid();
          DrawGridLog();
          PlotData();
+         if ( strcmp(p_plot_param->axis_type, "linear") == 0 )
+            {
+            PlotRectangles();
+            PlotEllipses();
+            }
          PlotLines();
          PlotSymbols();
          DrawTickLabels();
