@@ -1,4 +1,4 @@
-/********************************************************************************
+/*******************************************************************************
 *
 * gsegraf.h
 *
@@ -22,7 +22,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-********************************************************************************/
+*******************************************************************************/
 
 
 #include <gnome.h>
@@ -150,13 +150,13 @@ double font_size_date_time,
 
 
 /* Declare plot-parameter variables and pointers */
-int *nfilenames, *nformats, *styleflags, axis_limits[6], ncontours;
+int *nfilenames, *nformats, *styleflags, axis_limits[6], ncontours, flag_close;
 unsigned int *stylesizes;
 guint32 *stylecolor1, *stylecolor2, *alphacolor, gridcolor;
-char *p_param_file, *filenames, *formats, *formats_mod, *plot_types,
-     *stylechar1, *stylechar2, gridchar1, gridchar2, *bin_values, *bin_refs,
-     *xlabel, *ylabel, *zlabel, *title, *font_name, date_time[21];
-double *zblack, *zwhite, *bin_widths;
+char *p_param_file, *p_tempfile, *filenames, *formats, *formats_mod, *plot_types,
+     *stylechar1, *stylechar2, gridchar1, gridchar2, *bin_values, *bin_refs, *stemflags,
+     *xlabel, *ylabel, *zlabel, *title, *save_filename, *font_name, date_time[21];
+double *zblack, *zwhite, *bin_widths, *stemvalues;
 
 
 /* Declare tick-label size variables */
@@ -357,7 +357,7 @@ void     DrawLineSegments ( int iplot, int index, int npts,
                             double xscale, double yscale, int linechar );
 
 void     PlotData3d ( void );
-
+void     PlotEllipses ( void );
 void     PlotInterp3d ( int iplot, double xmin, double ymin, double zmin, double zmax,
                         double xscale, double yscale, double zscale,
                         double *origin, double *Ryz, guint32 *fill_color,
@@ -378,6 +378,7 @@ void     DrawLineSegments3d ( int iplot, int index, int npts, double *origin, do
                               double xmin, double xmax, double ymin, double ymax, double zmin, double zmax,
                               double xscale, double yscale, double zscale, int linechar );
 
+void     PlotRectangles ( void );
 void     PlotSymbols ( void );
 
 /* PolarPlot.c */
